# -*- coding: utf-8 -*-
from api import API
import sys
import os
import time
import routing
import requests
import json
import urllib
from artwork import ArtworkWindow
from xbmc import Player, sleep, log, executebuiltin, translatePath, getCondVisibility
from xbmcaddon import Addon
from xbmcgui import ListItem, getCurrentWindowDialogId
from xbmcplugin import addDirectoryItem, endOfDirectory, setContent, setResolvedUrl


ADDON = Addon()
ADDON_HANDLE = int(sys.argv[1])
PLUGIN = routing.Plugin()
USERDATA_DIR = translatePath('special://userdata/addon_data/plugin.audio.99fm-playlists')
api = API()


@PLUGIN.route('/')
def index():
    """
    Shows channels list
    :return:
    """
    for index, category in enumerate(api.get_channels()):
        try:
            bg_image = urllib.quote(category['bgImage'], safe=':/')
        except:
            bg_image = PLUGIN.addon.getAddonInfo('fanart')
            pass

        # list item:
        li = ListItem(u'{0}'.format(category['title'].upper()),
                      iconImage=bg_image,
                      thumbnailImage=bg_image)
        li.setArt({
            'fanart': bg_image
        })
        li.setInfo('music', {
            'Title': u'{0} - {1}'.format(category['title'].upper(), category['slogan']),
        })
        # directory item:
        addDirectoryItem(
            PLUGIN.handle,
            PLUGIN.url_for(show_playlists, url=urllib.quote(category['url'], safe=':/')),
            li,
            True
        )
    # end of directory:
    endOfDirectory(PLUGIN.handle)


@PLUGIN.route('/playlists')
def show_playlists():
    """
    Shows playlists in a channel
    :param index: Channel index
    :return:
    """
    for idx, playlist in enumerate(api.get_playlists(urllib.unquote(PLUGIN.args['url'][0]))):
        try:
            bg_image = urllib.quote(playlist['bgImage'], safe=':/')
        except:
            bg_image = PLUGIN.addon.getAddonInfo('fanart')
            pass

        # list item:
        li = ListItem(u'{0}'.format(playlist['title'].upper()),
                      iconImage=bg_image,
                      thumbnailImage=bg_image)
        li.setArt({
            'fanart': bg_image
        })
        li.setProperty('IsPlayable', 'true')
        li.setInfo('music', {
            'Title': u'{0} - {1}'.format(playlist['title'].upper(), playlist['slogan']),
        })
        # set the content of the directory
        setContent(ADDON_HANDLE, 'songs')
        # directory item:
        addDirectoryItem(
                PLUGIN.handle,
                PLUGIN.url_for(play_song, url=urllib.quote(playlist['url'], safe=':/'), poster=bg_image),
                li,
                False
        )
    # end of directory:
    endOfDirectory(PLUGIN.handle)


@PLUGIN.route('/playlist')
def play_song():
    playlist = api.get_playlist(urllib.unquote(PLUGIN.args['url'][0]))
    songs_timing = api.get_timing(urllib.unquote(PLUGIN.args['url'][0]))

    try:
        bg_image = urllib.quote(PLUGIN.args['poster'][0], safe=':/')
    except:
        bg_image = ADDON.getAddonInfo('fanart')
        pass

    # url = urllib.quote(playlist['songs'][0]['url'], safe=':/?=')
    # try:
    #     response = requests.head(url, allow_redirects=False)
    #     if 'location' in response.headers:
    #         url = response.headers['location']
    # except:
    #     pass

    li = ListItem(playlist['title'],
                  playlist['slogan'], bg_image, bg_image,
                  urllib.quote(playlist['mp3'], safe=':/'))
    li.setArt({'thumb': bg_image, 'fanart': bg_image})
    li.setInfo('music', {'Title': playlist['title'], 'Artist': playlist['slogan']})
    li.setProperty('mimetype', 'audio/mpeg')
    li.setProperty('IsPlayable', 'true')
    li.setInfo('music', {
        'Title': playlist['title'].upper(),
        'Artist': playlist['slogan']
    })

    setResolvedUrl(ADDON_HANDLE, True, listitem=li)
    if ADDON.getSetting('nowplaying') == 'false':
        update_now_playing(playlist, songs_timing, urllib.quote(playlist['mp3'], safe=':/'),
                           bg_image)


def update_now_playing(playlist, songs_timing, mp3_url, poster):
    last_item = None
    label = None

    artwork = ArtworkWindow()
    artwork.show()
    artwork_id = getCurrentWindowDialogId()

    while not Player().isPlaying():
        sleep(5000)

    while Player().isPlaying() and Player().getPlayingFile() == mp3_url and getCondVisibility('Window.IsVisible({0})'.format(artwork_id)):
        current_time = Player().getTime()

        if current_time < 30:
            last_item = songs_timing[0]
        else:
            for item in songs_timing:
                if current_time < item['seconds']:
                    break
                last_item = item

        if last_item:
            if label != last_item['title']:
                label = last_item['title']
                bg_image = last_item['icon']

                artwork.overlay.setImage(poster)
                artwork.cover.setImage(bg_image)
                artwork.song.setLabel('[B]{0}[/B]'.format(last_item['title'].split('-')[0].encode('utf-8')))
                artwork.artist.setLabel(last_item['title'].split('-')[1].encode('utf-8'))

        sleep(5000)

    artwork.close()


def calc_fractional_seconds(time_label):
    time = time_label.split(':')
    return int(time[0]) * 3600 + int(time[1]) * 60 + int(time[2])


if __name__ == '__main__':
    PLUGIN.run()
    setContent(PLUGIN.handle, 'audio')
